package Yaa::LookupMap::Driver::MYDRIVER;

# inherit everything from Yaa::LookupMap
@ISA = qw(Yaa::LookupMap);

use strict;
use vars qw ($VERSION);

# set debugging constant if YAA_DEBUG environment variable is set
BEGIN {
	use constant DEBUG => ((defined $ENV{YAA_DEBUG}) ? 1 : 0);
	require File::Basename if (DEBUG);
}

######################################################
#                GLOBAL VARIABLES                    #
######################################################
my $VERSION = "10.x";

######################################################
#               OBJECT CONSTRUCTOR                   #
######################################################

sub new {
	my $proto = shift;
	my $class = ref($proto) || $proto;
	
	# call parent constructor
	my $self = Yaa::LookupMap->new();

	##################################################
	#               PUBLIC VARS                      #
	##################################################
	
	# my custom obj property
	$self->{my_property} = undef;
	
	##################################################
	#              PRIVATE VARS                      #
	##################################################
	
	# my private prop
	$self->{_private_prop} = undef;

	bless($self, $class);

	# clear parameters
	$self->clearParams();

	# set object properties	
	$self->setParams(@_);
	
	return $self;
}

####################################################
#               PUBLIC METHODS                     #
####################################################

sub clearParams {
	my ($self) = @_;
	$self->{my_property} = undef;
	$self->{_private_prop} = undef;
}

####################################################
#               PRIVATE METHODS                    #
####################################################
sub _lookup {
	my ($self, $key) = @_;
	
	print STDERR "DEBUG: ",  File::Basename::basename(__FILE__), ", _lookup(), line ", __LINE__, ": got query key '$key'\n" if (DEBUG);

	my $result = Yaa::LookupMap::Result->new();
	
	# query something
	if (query_ok()) {
		$result->addMatch({ result => 'result_value' });
	} else {
		$self->{error} = "Lookup failed.";
		return undef;
	}
	
	return $result;
}

1;
